@@ -8,8 +8,14 @@
 #' 
 #' @param obj object of the class \code{formation}
 #' @param lineup lineup of the corresponding object \code{obj}
+#' @param Hard matrix of hardness to be used
 #' 
-#' @return \code{vector} of the adjusted lineup for the red card(s)
+#' @return \code{list} with two elements: 
+#' \itemize{
+#'  \item{\code{vector}}{ adjusted lineup for the red card(s)}
+#'  \item{\code{numeric}}{ number of red cards}
+#' }
+#'
 #'
 #' @name simRedCard
 NULL
@@ -17,4 +23,4 @@ NULL
 #' @rdname simRedCard
 #' 
 #' @export
-setGeneric("simRedCard", function(obj, lineup) standardGeneric("simRedCard"))
\ No newline at end of file
+setGeneric("simRedCard", function(obj, lineup, Hard) standardGeneric("simRedCard"))
\ No newline at end of file
